import QtQuick 2.0
import Ubuntu.Components 0.1



Page {
    id: resistorPage
    tools:  toolbarActions
    
    Rectangle {
        id:resistorContainer
        x:units.gu(1)
        y:units.gu(1)
        width:parent.width-units.gu(2)
        height:parent.height-units.gu(2)
        clip:false
        color: "transparent"
        
        //select tolerance and colors of resistor
        ResistorToleranceBand{id:bandtolerance;bandValue:5;y:resistor.height+units.gu(2)+50}
        ResistorValueBand{id:band1select;bandColor:'brown';bandValue:1;width:parent.width;y:resistor.height+units.gu(2)+100}
        ResistorValueBand{id:band2select;width:parent.width;y:resistor.height+units.gu(2)+150}
        ResistorValueBand{id:band3select;width:parent.width;y:resistor.height+units.gu(2)+200}
        ResistorValueBand{id:band4select;width:parent.width;y:resistor.height+units.gu(2)+250;visible:false;}
        
        property int customHeight:height/2;
        property int selectedResistor:1;
        property int calculationType:1;

        Image {
            id: resistor
            width: parent.width
            height: parent.width/3
            smooth:true
            source: "resistor-single.svg"
            sourceSize.width:width
            sourceSize.height:height
            fillMode: Image.PreserveAspectFit
            anchors.margins:units.gu(4)

            ResistorColorBand {
              id:resistorOneColorBand
              onClicked: {
                resistorContainer.selectedResistor=1
                tolerance.text ='1'
              }
            }
            ResistorColorBand {
              id:resistorTwoColorBand
              visible:false
              onClicked: {
                resistorContainer.selectedResistor=2
                tolerance.text ='2'
              }
            }
            
        }

        Label {
            id:resistance
            text:'0 ohms'
            color:'black'
            y:resistor.height
            x:0
            verticalAlignment:Text.AlignVCenter
            horizontalAlignment:Text.AlignHCenter
            width:parent.width
        }
        
        Label {
            id:tolerance
            text:'Tolerance 5%'
            color:'black'
            y:resistor.height+20
            x:0
            verticalAlignment:Text.AlignVCenter
            horizontalAlignment:Text.AlignHCenter
            width:parent.width
        }
    }
    
  ToolbarActions {
      id: toolbarActions
      Action {
          text: "3 Bands"
          iconSource: "resistor-small-rotated.svg"
          onTriggered: {
            resistorPage.show3bands()
            band1select.update()
          }
      }
      
      Action {
          text: "4 Bands"
          iconSource: "resistor-small-rotated.svg"
          enabled: true
          onTriggered: {
            resistorPage.show4bands()
            band1select.update()
          }
      }

      Action {
          text: "Parallel"
          iconSource: "resistor-small-rotated.svg"
          enabled: true
          onTriggered: {
          resistorTwoColorBand.visible=true;
            resistorPage.setParallel()
          }
      }

      Action {
          text: "Series"
          iconSource: "resistor-small-rotated.svg"
          enabled: true
          onTriggered: {
          resistorTwoColorBand.visible=true;
            resistorPage.setSeries()
          }
      }

      Action {
          text: "Single"
          iconSource: "resistor-small-rotated.svg"
          enabled: true
          onTriggered: {
            resistorTwoColorBand.visible=false;
            resistorPage.setSingle()
          }
      }

      back {
          visible: true
          onTriggered: toolsSwitch.checked = false
      }
  }
    
    function show3bands(){
        resistorOneColorBand.fourBands = false
        resistorTwoColorBand.fourBands = false
        band4select.visible = false
    }

    function show4bands(){
        resistorOneColorBand.fourBands = true
        resistorTwoColorBand.fourBands = true
        band4select.visible = true
    }
    
    function update(){
      if (resistorContainer.selectedResistor==1){
          
          resistorOneColorBand.firstBandColor=band1select.bandColor;
          resistorOneColorBand.secondBandColor=band2select.bandColor;
          if(resistorOneColorBand.fourBands==false ){
            resistorOneColorBand.multiplyBandColor=band3select.bandColor;   
          }else{
            resistorOneColorBand.thirdBandColor=band3select.bandColor;
            resistorOneColorBand.multiplyBandColor=band4select.bandColor;             
          }       
          
          //update values
          resistorOneColorBand.band1value=band1select.bandValue;
          resistorOneColorBand.band2value=band2select.bandValue;
          resistorOneColorBand.band3value=band3select.bandValue;
          resistorOneColorBand.band4value=band4select.bandValue;
          
          resistorOneColorBand.toleranceBandColor=bandtolerance.bandColor;
          resistorOneColorBand.update();
      }else{
          resistorTwoColorBand.firstBandColor=band1select.bandColor;
          resistorTwoColorBand.secondBandColor=band2select.bandColor;
          if(resistorTwoColorBand.fourBands==false ){
            resistorTwoColorBand.multiplyBandColor=band3select.bandColor;   
          }else{
            resistorTwoColorBand.thirdBandColor=band3select.bandColor;
            resistorTwoColorBand.multiplyBandColor=band4select.bandColor;             
          }   
          
          //update values
          resistorTwoColorBand.band1value=band1select.bandValue;
          resistorTwoColorBand.band2value=band2select.bandValue;
          resistorTwoColorBand.band3value=band3select.bandValue;
          resistorTwoColorBand.band4value=band4select.bandValue;
              
          resistorTwoColorBand.toleranceBandColor=bandtolerance.bandColor;
          resistorTwoColorBand.update();
      }
      calculation()
    }

    function format(value){
        value=value+''
        var startOffset=0;
        var zeros='';
        var character='';
        
        if(value.length>2){startOffset=3;character='K';}
        if(value.length>4){startOffset=5;character='M';}
        zeros=value.substr(0,startOffset);

        return zeros+character;
    }    

    function calculation(){
        if(resistorContainer.calculationType==1){//single
          resistance.text=format(resistorOneColorBand.calculate())
        }
        if(resistorContainer.calculationType==2){//series
          resistance.text=format((resistorOneColorBand.calculate()+resistorTwoColorBand.calculate()))
        }
        if(resistorContainer.calculationType==3){//parallel
          resistance.text=format((1/((1/resistorOneColorBand.calculate())+(1/resistorTwoColorBand.calculate()))))
        }
        tolerance.text = 'Tolerance '+bandtolerance.bandValue+'%';
    }
    
    function setSingle(){
       resistor.source = "resistor-single.svg"
       resistorOneColorBand.width=width/3.5
       resistorOneColorBand.height=resistor.height/2
       resistorOneColorBand.anchors.verticalCenterOffset=0
       resistorOneColorBand.anchors.horizontalCenterOffset=0
       resistorTwoColorBand.visible=false
       resistorContainer.calculationType=1
    }
    
    function setSeries(){
       resistor.source = "resistor-series.svg"
       resistorOneColorBand.width=width/6.5
       resistorOneColorBand.height=resistor.height/3
       resistorOneColorBand.anchors.horizontalCenterOffset=(width/4.5);
       resistorOneColorBand.anchors.verticalCenterOffset=0;
       resistorOneColorBand.visible=true
       
       resistorTwoColorBand.width=width/6.5
       resistorTwoColorBand.height=resistor.height/3
       resistorTwoColorBand.anchors.horizontalCenterOffset=-(width/4.5);
       resistorTwoColorBand.anchors.verticalCenterOffset=0;
       resistorTwoColorBand.visible=true
       resistorContainer.calculationType=2
    }
    
    function setParallel(){
       resistor.source = "resistor-parallel.svg"
       resistorOneColorBand.width=width/6.5
       resistorOneColorBand.height=resistor.height/3
       resistorOneColorBand.anchors.horizontalCenterOffset=0;
       resistorOneColorBand.anchors.verticalCenterOffset=(resistor.height/4);
       resistorOneColorBand.visible=true
       
       resistorTwoColorBand.width=width/6.5
       resistorTwoColorBand.height=resistor.height/3
       resistorTwoColorBand.anchors.horizontalCenterOffset=0;
       resistorTwoColorBand.anchors.verticalCenterOffset=-(resistor.height/4);
       resistorTwoColorBand.visible=true
       resistorContainer.calculationType=3
    }
    
}


